MidCOM svn: r14335 - in trunk/midcom:
com.magnettechnologies.contactgrabber/lib/gmail
com.magnettechnologies.contactgrabber/lib/hotmail
com.magnettechnologies.contactgrabber/lib/myspace
com.magnettechnologies....
flack
midcom-commits at lists.midgard-project.org
Wed Jan 9 17:07:18 CET 2008
Author: flack
Date: Wed Jan 9 17:07:17 2008
New Revision: 14335
URL: http://trac.midgard-project.org/software/changeset/14335
Log:
PHPdoc fixes for @see tags on some warnings
Modified:
trunk/midcom/com.magnettechnologies.contactgrabber/lib/gmail/libgmailer.php
trunk/midcom/com.magnettechnologies.contactgrabber/lib/hotmail/msn_contact_grab.class.php
trunk/midcom/com.magnettechnologies.contactgrabber/lib/myspace/grabMyspace.class.php
trunk/midcom/com.magnettechnologies.contactgrabber/lib/orkut/grabOrkut.class.php
trunk/midcom/com.magnettechnologies.contactgrabber/lib/rediff/grabRediff.class.php
trunk/midcom/com.magnettechnologies.contactgrabber/lib/yahoo/class.GrabYahoo.php
trunk/midcom/com.magnettechnologies.contactgrabber/lib/yahoo/config.php
trunk/midcom/de.bitfolge.feedcreator/feedcreator.php
trunk/midcom/midcom.admin.styleeditor/admin.php
trunk/midcom/midcom.core/midcom/application.php
trunk/midcom/midcom.core/midcom/baseclasses/components/request.php
trunk/midcom/midcom.core/midcom/exec/about.php
trunk/midcom/midcom.core/midcom/exec/config-test.php
trunk/midcom/midcom.core/midcom/exec/convert_legacy_metadata.php
trunk/midcom/midcom.core/midcom/exec/convert_legacy_topics.php
trunk/midcom/midcom.core/midcom/exec/cron.php
trunk/midcom/midcom.core/midcom/exec/index-legacy-attachments.php
trunk/midcom/midcom.core/midcom/helper/metadata.php
trunk/midcom/midcom.core/midcom/request.php
trunk/midcom/midcom.core/midcom/services/auth.php
trunk/midcom/midcom.core/support/importStyle.php
trunk/midcom/midcom.helper.datamanager/datatype.php
trunk/midcom/midcom.helper.datamanager/lib_markdown.php
trunk/midcom/midcom.helper.datamanager/widget_account.php
trunk/midcom/midcom.helper.datamanager2/type/select.php
trunk/midcom/midgard.admin.sitegroup/bin/create-host.php
trunk/midcom/midgard.admin.sitegroup/bin/create-sitegroup.php
trunk/midcom/midgard.admin.sitegroup/creation/host.php
trunk/midcom/midgard.admin.sitewizard/sitetemplate.php
trunk/midcom/net.nehmer.account/plugins/midgard_admin_sitewizard_plugin.php
trunk/midcom/net.nehmer.markdown/lib/markdown.php
trunk/midcom/net.nemein.rss/feed.php
trunk/midcom/net.nemein.teams/plugins/midgard_admin_sitewizard_plugin.php
trunk/midcom/net.nemein.wiki/link.php
trunk/midcom/no.bergfald.rcs/backends/aegir_rcs_functions.php
trunk/midcom/no.bergfald.rcs/backends/nemein_rcs_functions.php
trunk/midcom/no.odindata.quickform2/emailgenerator.php
trunk/midcom/org.openpsa.directmarketing/support/link_detector.php
trunk/midcom/org.openpsa.documents/document_midcomdba.php
trunk/midcom/org.openpsa.helpers/array2code.php
trunk/midcom/org.openpsa.helpers/dm_savecancel.php
trunk/midcom/org.openpsa.helpers/resources.php
trunk/midcom/org.openpsa.helpers/schema_modifier.php
trunk/midcom/org.openpsa.helpers/sprint_r.php
trunk/midcom/org.openpsa.helpers/task_groups.php
trunk/midcom/org.openpsa.helpers/tasks.php
trunk/midcom/org.openpsa.helpers/workgroups.php
trunk/midcom/org.openpsa.sales/sort_helper.php
trunk/midcom/org.routamc.photostream/midcom/interfaces.php
trunk/midcom/org.routamc.photostream/phpFlickr.php
trunk/midcom/se.anykey.mmslib/mmslib.php
Modified: trunk/midcom/com.magnettechnologies.contactgrabber/lib/gmail/libgmailer.php
==============================================================================
--- trunk/midcom/com.magnettechnologies.contactgrabber/lib/gmail/libgmailer.php (original)
+++ trunk/midcom/com.magnettechnologies.contactgrabber/lib/gmail/libgmailer.php Wed Jan 9 17:07:17 2008
@@ -1,4 +1,7 @@
<?php
+/**
+ * @package com.magnettechnologies.contactgrabber
+ */
/**
* Contact Grabber
Modified: trunk/midcom/com.magnettechnologies.contactgrabber/lib/hotmail/msn_contact_grab.class.php
==============================================================================
--- trunk/midcom/com.magnettechnologies.contactgrabber/lib/hotmail/msn_contact_grab.class.php (original)
+++ trunk/midcom/com.magnettechnologies.contactgrabber/lib/hotmail/msn_contact_grab.class.php Wed Jan 9 17:07:17 2008
@@ -1,4 +1,7 @@
<?php
+/**
+ * @package com.magnettechnologies.contactgrabber
+ */
/*
This class connects to the MSNM service and returns
Modified: trunk/midcom/com.magnettechnologies.contactgrabber/lib/myspace/grabMyspace.class.php
==============================================================================
--- trunk/midcom/com.magnettechnologies.contactgrabber/lib/myspace/grabMyspace.class.php (original)
+++ trunk/midcom/com.magnettechnologies.contactgrabber/lib/myspace/grabMyspace.class.php Wed Jan 9 17:07:17 2008
@@ -1,4 +1,7 @@
<?php
+/**
+ * @package com.magnettechnologies.contactgrabber
+ */
/**
* Contact Grabber
Modified: trunk/midcom/com.magnettechnologies.contactgrabber/lib/orkut/grabOrkut.class.php
==============================================================================
--- trunk/midcom/com.magnettechnologies.contactgrabber/lib/orkut/grabOrkut.class.php (original)
+++ trunk/midcom/com.magnettechnologies.contactgrabber/lib/orkut/grabOrkut.class.php Wed Jan 9 17:07:17 2008
@@ -1,4 +1,7 @@
<?php
+/**
+ * @package com.magnettechnologies.contactgrabber
+ */
/**
* Contact Grabber
Modified: trunk/midcom/com.magnettechnologies.contactgrabber/lib/rediff/grabRediff.class.php
==============================================================================
--- trunk/midcom/com.magnettechnologies.contactgrabber/lib/rediff/grabRediff.class.php (original)
+++ trunk/midcom/com.magnettechnologies.contactgrabber/lib/rediff/grabRediff.class.php Wed Jan 9 17:07:17 2008
@@ -1,4 +1,7 @@
<?php
+/**
+ * @package com.magnettechnologies.contactgrabber
+ */
/**
* Contact Grabber
Modified: trunk/midcom/com.magnettechnologies.contactgrabber/lib/yahoo/class.GrabYahoo.php
==============================================================================
--- trunk/midcom/com.magnettechnologies.contactgrabber/lib/yahoo/class.GrabYahoo.php (original)
+++ trunk/midcom/com.magnettechnologies.contactgrabber/lib/yahoo/class.GrabYahoo.php Wed Jan 9 17:07:17 2008
@@ -1,4 +1,7 @@
<?php
+/**
+ * @package com.magnettechnologies.contactgrabber
+ */
/**
* Contact Grabber
Modified: trunk/midcom/com.magnettechnologies.contactgrabber/lib/yahoo/config.php
==============================================================================
--- trunk/midcom/com.magnettechnologies.contactgrabber/lib/yahoo/config.php (original)
+++ trunk/midcom/com.magnettechnologies.contactgrabber/lib/yahoo/config.php Wed Jan 9 17:07:17 2008
@@ -1,4 +1,7 @@
<?php
+/**
+ * @package com.magnettechnologies.contactgrabber
+ */
/**
* Contact Grabber
Modified: trunk/midcom/de.bitfolge.feedcreator/feedcreator.php
==============================================================================
--- trunk/midcom/de.bitfolge.feedcreator/feedcreator.php (original)
+++ trunk/midcom/de.bitfolge.feedcreator/feedcreator.php Wed Jan 9 17:07:17 2008
@@ -1,4 +1,7 @@
<?php
+/**
+ * @package de.bitfolge.feedcreator
+ */
/***************************************************************************
FeedCreator class v1.7.7(BH)
@@ -112,7 +115,7 @@
initial release
- at package de.bitfolge.feedcreator
+
***************************************************************************/
/*** GENERAL USAGE *********************************************************
Modified: trunk/midcom/midcom.admin.styleeditor/admin.php
==============================================================================
--- trunk/midcom/midcom.admin.styleeditor/admin.php (original)
+++ trunk/midcom/midcom.admin.styleeditor/admin.php Wed Jan 9 17:07:17 2008
@@ -15,14 +15,14 @@
/**
* the current topic we are in
- *
+ *
* @var current_topic
* @access public
*/
var $_current_topic = 0;
-
+
/**
- * pointer to midcom_session_object
+ * pointer to midcom_session_object
*/
var $_session = null;
@@ -311,7 +311,7 @@
* Display the content, it uses the handler as determined by can_handle.
* This overrides the basic show method of the class to include the ais style around the component.
*
- * @see _on_show();
+ * @see _on_show()
*/
function show()
{
Modified: trunk/midcom/midcom.core/midcom/application.php
==============================================================================
--- trunk/midcom/midcom.core/midcom/application.php (original)
+++ trunk/midcom/midcom.core/midcom/application.php Wed Jan 9 17:07:17 2008
@@ -367,7 +367,7 @@
*
* @var string
* @access private
- * @see midcom_application::get_host_prefix();
+ * @see get_host_prefix()
*/
private $_cached_host_prefix = '';
@@ -376,7 +376,7 @@
*
* @var string
* @access private
- * @see midcom_application::get_page_prefix();
+ * @see get_page_prefix()
*/
private $_cached_page_prefix = '';
@@ -385,7 +385,7 @@
*
* @var string
* @access private
- * @see midcom_application::get_host_name();
+ * @see get_host_name()
*/
private $_cached_host_name = '';
@@ -544,7 +544,7 @@
*
* This function must be called before any output starts.
*
- * @see midcom_application::_process()
+ * @see _process()
*/
public function codeinit()
{
@@ -1010,7 +1010,7 @@
$path = $object->component;
if (!$path)
{
- $path = 'midcom.core.nullcomponent';
+ $path = 'midcom.core.nullcomponent';
debug_add("No component defined for this node.", MIDCOM_LOG_ERROR);
debug_print_r("Root node:",$object,MIDCOM_LOG_DEBUG);
}
@@ -1568,7 +1568,7 @@
* @param mixed $value The value to be stored
* @param int $param1 See get_context_data()
* @param int $param2 See get_context_data()
- * @see midcom_application::get_context_data()
+ * @see get_context_data()
* @access private
*/
function _set_context_data($value, $param1, $param2 = null)
@@ -1637,7 +1637,7 @@
* @param mixed $key The key associated to the value.
* @param mixed $value The value to store. (This is stored by-reference!)
* @param int $contextid The context to associated this data with (defaults to the current context)
- * @see midcom_application::get_custom_context_data()
+ * @see get_custom_context_data()
*/
function set_custom_context_data ($key, &$value, $contextid = null) {
if (is_null($contextid))
@@ -1664,8 +1664,8 @@
* @param int $param1 See get_context_data()
* @param int $param2 See get_context_data()
* @return mixed The requested value, which is returned by Reference!
- * @see midcom_application::get_context_data()
- * @see midcom_application::set_custom_context_data()
+ * @see get_context_data()
+ * @see set_custom_context_data()
*/
function & get_custom_context_data($param1, $param2 = null)
{
@@ -1732,7 +1732,7 @@
* be available.
*
* @param string $newsub The substyle to append.
- * @see midcom_application::substyle_prepend()
+ * @see substyle_prepend()
*/
function substyle_append ($newsub)
{
@@ -1766,7 +1766,7 @@
* be available.
*
* @param string $newsub The substyle to prepend.
- * @see midcom_application::substyle_append()
+ * @see substyle_append()
*/
function substyle_prepend($newsub)
{
@@ -2550,10 +2550,10 @@
*
* @param string $url The URL to the file to-be referenced.
* @param boolean $prepend Whether to add the JS include to beginning of includes
- * @see midcom_application::add_jscript();
- * @see midcom_application::add_jsonload();
- * @see midcom_application::print_jscripts();
- * @see midcom_application::print_jsonload();
+ * @see add_jscript()
+ * @see add_jsonload()
+ * @see print_jscripts()
+ * @see print_jsonload()
*/
function add_jsfile($url, $prepend = false)
{
@@ -2604,10 +2604,10 @@
* The sequence of the add_jsfile and add_jscript commands is kept stable.
*
* @param string $script The code to be included directly in the page.
- * @see midcom_application::add_jsfile();
- * @see midcom_application::add_jsonload();
- * @see midcom_application::print_jscripts();
- * @see midcom_application::print_jsonload();
+ * @see add_jsfile()
+ * @see add_jsonload()
+ * @see print_jscripts()
+ * @see print_jsonload()
*/
function add_jscript($script, $defer = '', $prepend = false)
{
@@ -2633,7 +2633,7 @@
*
* @param string $script The code to be included in the state.
* @param string $state The state where to include the code to. Defaults to document.ready
- * @see midcom_application::print_jquery_statuses();
+ * @see print_jquery_statuses()
*/
function add_jquery_state_script($script, $state = 'document.ready')
{
@@ -2657,7 +2657,7 @@
*
* @param string $script The input between the <object></object> tags.
* @param array $attributes Array of attribute=> value pairs to be placed in the tag.
- * @see midcom_application::print_head();
+ * @see print_head()
*
*/
@@ -2676,7 +2676,7 @@
* head section of the page.
*
* @param array $attributes Array of attribute=> value pairs to be placed in the tag.
- * @see midcom_application::print_head();
+ * @see print_head()
*/
function add_meta_head($attributes = null)
{
@@ -2695,7 +2695,7 @@
*
* @param string $script The input between the <style></style> tags.
* @param array $attributes Array of attribute=> value pairs to be placed in the tag.
- * @see midcom_application::print_head();
+ * @see print_head()
*/
function add_style_head($script, $attributes = null)
{
@@ -2719,7 +2719,7 @@
* </pre>
*
* @param array $attributes Array of attribute=> value pairs to be placed in the tag.
- * @see midcom_application::print_head();
+ * @see print_head()
*/
function add_link_head( $attributes = null )
{
@@ -2790,10 +2790,10 @@
* backwards-compatibility.
*
* @param string $method The name of the method to be called on page startup, including parameters but excluding the ';'.
- * @see midcom_application::add_jsfile();
- * @see midcom_application::add_jscript();
- * @see midcom_application::print_jscripts();
- * @see midcom_application::print_jsonload();
+ * @see add_jsfile()
+ * @see add_jscript()
+ * @see print_jscripts()
+ * @see print_jsonload()
*/
function add_jsonload($method)
{
@@ -2830,10 +2830,10 @@
* </HTML>
* </code>
*
- * @see midcom_application::add_jsfile();
- * @see midcom_application::add_jscript();
- * @see midcom_application::add_jsonload();
- * @see midcom_application::print_jscripts();
+ * @see add_jsfile()
+ * @see add_jscript()
+ * @see add_jsonload()
+ * @see print_jscripts()
*/
function print_jsonload()
{
@@ -2858,12 +2858,12 @@
* clean site, just omit the print calls and you should be fine in almost all
* cases.
*
- * @see midcom_application::add_link_head
- * @see midcom_application::add_object_head
- * @see midcom_application::add_style_head
- * @see midcom_application::add_meta_head
- * @see midcom_application::add_jsfile();
- * @see midcom_application::add_jscript();
+ * @see add_link_head
+ * @see add_object_head
+ * @see add_style_head
+ * @see add_meta_head
+ * @see add_jsfile()
+ * @see add_jscript()
*/
function print_head_elements()
{
@@ -2935,8 +2935,8 @@
*
* This method is called from print_head_elements method.
*
- * @see midcom_application::add_jquery_state_script
- * @see midcom_application::print_head_elements
+ * @see add_jquery_state_script
+ * @see print_head_elements
*/
function print_jquery_statuses()
{
Modified: trunk/midcom/midcom.core/midcom/baseclasses/components/request.php
==============================================================================
--- trunk/midcom/midcom.core/midcom/baseclasses/components/request.php (original)
+++ trunk/midcom/midcom.core/midcom/baseclasses/components/request.php Wed Jan 9 17:07:17 2008
@@ -635,7 +635,7 @@
* @param int $argc The argument count
* @param Array $argv The argument list
* @return boolean Indicating whether the request was handled successfully.
- * @see _on_handle();
+ * @see _on_handle()
*/
public function handle($argc, $argv)
{
@@ -769,7 +769,7 @@
* generic preparation. If this function returns false, the regular output
* handler will not be called.
*
- * @see _on_show();
+ * @see _on_show()
*/
public function show()
{
Modified: trunk/midcom/midcom.core/midcom/exec/about.php
==============================================================================
--- trunk/midcom/midcom.core/midcom/exec/about.php (original)
+++ trunk/midcom/midcom.core/midcom/exec/about.php Wed Jan 9 17:07:17 2008
@@ -70,7 +70,7 @@
if ( $_MIDGARD['config']['quota']
&& class_exists('midgard_quota'))
{
- $qb = new midgard_query_builder('midgard_quota');
+ $qb = new MidgardQueryBuilder('midgard_quota');
$qb->add_constraint('tablename', '=', 'wholesg');
$qb->add_constraint('typename', '=', '');
$quotas = $qb->execute();
Modified: trunk/midcom/midcom.core/midcom/exec/config-test.php
==============================================================================
--- trunk/midcom/midcom.core/midcom/exec/config-test.php (original)
+++ trunk/midcom/midcom.core/midcom/exec/config-test.php Wed Jan 9 17:07:17 2008
@@ -146,12 +146,20 @@
}
// Some helpers
-$i18n =& $_MIDCOM->get_service('i18n');
+$i18n =& $GLOBALS['midcom']->get_service('i18n');
+
+// Check the PHP Version and PHP_Compat availability
$version = phpversion();
-if (version_compare($version, '5.1.0', '<'))
+if (version_compare($version, '4.1.0', '<'))
+{
+ println('PHP Version', ERROR, 'PHP 4.1.0 or greater is required for MidCOM, 4.3.0 or greater is recommended.');
+}
+else if (version_compare($version, '4.3.0', '<'))
{
- println('PHP Version', ERROR, 'PHP 5.1.0 or greater is required for MidCOM, 4.3.0 or greater is recommended.');
+ println('PHP Version', WARNING, 'PHP 4.3.0 or greater is recommended for MidCOM.');
+ println_check_for_include_file('PHP/Compat.php', 'PEAR Package: PHP_Compat',
+ ERROR, 'The PEAR Package PHP_Compat is required for pre-4.3.0 installations.');
}
else
{
@@ -300,7 +308,7 @@
$overload = ini_get('mbstring.func_overload');
if ($overload != '7')
{
- println('Multi-Byte String functions', WARNING, 'The Multi-Byte String functions are available, but this is a UTF-8 site and Function overloading is disabled, this is not recommended since string operations are erronous then.');
+ println('Multi-Byte String functions', WARNING, 'The Multi-Byte String functions are available, but this is an UTF-8 site and Function overloading is disabled, this is not recommended since string operations are erronous then.');
}
else
{
@@ -386,7 +394,7 @@
exec ($cmd, $output, $result);
if ($result != 0)
{
- println('External Utility: ImageMagick', ERROR, 'The existence ImageMagick toolkit could not be verified, it is required for all kinds of image processing in MidCOM.');
+ println('External Utility: ImageMagick', ERROR, 'The existance ImageMagick toolkit could not be verified, it is required for all kinds of image processing in MidCOM.');
}
else
{
Modified: trunk/midcom/midcom.core/midcom/exec/convert_legacy_metadata.php
==============================================================================
--- trunk/midcom/midcom.core/midcom/exec/convert_legacy_metadata.php (original)
+++ trunk/midcom/midcom.core/midcom/exec/convert_legacy_metadata.php Wed Jan 9 17:07:17 2008
@@ -22,7 +22,7 @@
$midgard = mgd_get_midgard();
if (! $midgard->admin)
{
- $_MIDCOM->generate_error(MIDCOM_ERRAUTH, "This script requires admin privileges to run.");
+ $GLOBALS['midcom']->generate_error(MIDCOM_ERRAUTH, "This script requires admin privileges to run.");
// This will exit.
}
@@ -78,7 +78,7 @@
$person = mgd_get_person($article->approver);
if (! $person)
{
- status ("<span style='color:red;'> Article {$article->id} had a broken approver id {$person->approver} (using current user as fallback): " . mgderrstr() . '</span>');
+ status ("<span style='color:red;'> Article {$article->id} had an broken approver id {$person->approver} (using current user as fallback): " . mgderrstr() . '</span>');
$person = mgd_get_person($midgard->user);
}
}
@@ -341,7 +341,7 @@
if ($childs === false)
{
echo "</pre>\n";
- $_MIDCOM->generate_error(MIDCOM_ERRCRIT, "Failed to list the child nodes of {$nodeid}. Aborting.");
+ $GLOBALS['midcom']->generate_error(MIDCOM_ERRCRIT, "Failed to list the child nodes of {$nodeid}. Aborting.");
}
$nodes = array_merge($nodes, $childs);
$nodeid = array_shift($nodes);
@@ -351,7 +351,7 @@
echo "\n\nData Conversion complete.\n\n";
echo "\n\nInvalidating the Content Cache...\n\n";
-$_MIDCOM->cache->invalidate_all();
+$GLOBALS['midcom']->cache->invalidate_all();
echo '</pre>';
?>
Modified: trunk/midcom/midcom.core/midcom/exec/convert_legacy_topics.php
==============================================================================
--- trunk/midcom/midcom.core/midcom/exec/convert_legacy_topics.php (original)
+++ trunk/midcom/midcom.core/midcom/exec/convert_legacy_topics.php Wed Jan 9 17:07:17 2008
@@ -14,6 +14,8 @@
*/
$_MIDCOM->auth->require_admin_user();
+ at ini_set('max_execution_time', 0);
+
$qb = midcom_db_topic::new_query_builder();
$qb->begin_group('AND');
$qb->add_constraint('parameter.domain', '=', 'midcom');
Modified: trunk/midcom/midcom.core/midcom/exec/cron.php
==============================================================================
--- trunk/midcom/midcom.core/midcom/exec/cron.php (original)
+++ trunk/midcom/midcom.core/midcom/exec/cron.php Wed Jan 9 17:07:17 2008
@@ -18,12 +18,12 @@
$_MIDCOM->auth->require_admin_user();
}
+$_MIDCOM->cache->content->enable_live_mode();
+
header('Content-Type: text/plain');
require(MIDCOM_ROOT . '/midcom/services/cron.php');
-$_MIDCOM->cache->content->enable_live_mode();
-
// Ensure cron doesn't timeout
@ini_set('max_execution_time', 0);
Modified: trunk/midcom/midcom.core/midcom/exec/index-legacy-attachments.php
==============================================================================
--- trunk/midcom/midcom.core/midcom/helper/metadata.php (original)
+++ trunk/midcom/midcom.core/midcom/helper/metadata.php Wed Jan 9 17:07:17 2008
@@ -152,7 +152,7 @@
* You will not get the data from the datamanager using this calls, but the only
* slightly post-processed metadata values. See _retrieve_value for post processing.
*
- * @see midcom_helper_metdata::_retrieve_value();
+ * @see midcom_helper_metdata::_retrieve_value()
* @param string $key The key to retrieve
* @return mixed The key's value.
*/
Modified: trunk/midcom/midcom.core/midcom/request.php
==============================================================================
--- trunk/midcom/midcom.core/midcom/request.php (original)
+++ trunk/midcom/midcom.core/midcom/request.php Wed Jan 9 17:07:17 2008
@@ -57,6 +57,8 @@
/**
* This one is thrown if the url does not map to anything
+ *
+ * @package midcom
*/
class midcom_url_notfound_exception extends Exception { }
@@ -65,6 +67,7 @@
* different parts of the parsing process.
*
*
+ * @package midcom
*/
class midcom_urlparserfactory {
@@ -100,6 +103,8 @@
}
/**
* Implements a simple representation of the url as a stack
+ *
+ * @package midcom
*/
class midcom_url_urlstack
{
@@ -127,6 +132,8 @@
/**
* This class is used to collect information to be used when executing the
* request
+ *
+ * @package midcom
*/
class midcom_url_paramcollector {
/**
@@ -213,6 +220,8 @@
* A parser for a part of a url
* The parser will get in the url where its work starts and will work greedily on that
* until it gets nothing and returns.
+ *
+ * @package midcom
*/
abstract class midcom_url_parser {
/**
@@ -240,12 +249,16 @@
* This class does not parse anything and used as a placeholder for the last_parser
* variable above.
*
+ * @package midcom
*/
class midcom_url_nullparser extends midcom_url_parser
{
public function __construct() {}
}
+/**
+ * @package midcom
+ */
class midcom_url_topicgetter {
public function get_topic($topic_name, $up) {
// todo!
@@ -254,6 +267,8 @@
}
/**
* This class parses any part of the url that is deemed to be related to topics
+ *
+ * @package midcom
*/
class midcom_url_topic extends midcom_url_parser
{
@@ -295,6 +310,8 @@
* /serveattachment
* /midcom-substyle
* etc
+ *
+ * @package midcom
*/
class midcom_url_midcom extends midcom_url_parser {
Modified: trunk/midcom/midcom.core/midcom/services/auth.php
==============================================================================
--- trunk/midcom/midcom.core/midcom/services/auth.php (original)
+++ trunk/midcom/midcom.core/midcom/services/auth.php Wed Jan 9 17:07:17 2008
@@ -433,8 +433,8 @@
*
* @var int
* @access private
- * @see request_sudo();
- * @see drop_sudo();
+ * @see request_sudo()
+ * @see drop_sudo()
*/
var $_component_sudo = 0;
@@ -1400,7 +1400,7 @@
$sitegroup = mgd_get_sitegroup();
$sitegroup->name = 'SG0';
}
-
+
if (!isset($_SERVER['PHP_AUTH_USER']))
{
header("WWW-Authenticate: Basic realm=\"{$sitegroup->name}\"");
Modified: trunk/midcom/midcom.core/support/importStyle.php
==============================================================================
--- trunk/midcom/midcom.core/support/importStyle.php (original)
+++ trunk/midcom/midcom.core/support/importStyle.php Wed Jan 9 17:07:17 2008
@@ -23,8 +23,8 @@
'desc' => 'Name of the midgard configuration file.',
'default' => 'midgard',
);
-
-
+
+
$args = Console_Getargs::factory($opts_config);
$header = "Usage: " .basename($_SERVER['SCRIPT_NAME'])." [options]\n\n" ;
@@ -45,13 +45,13 @@
echo "using config: " . $args->getValue('configuration') . "\n";
mgd_config_init($args->getValue('configuration'));
}
-
+
function run () {
$dir = $this->args->getValue(CONSOLE_GETARGS_PARAMS);
if (!is_dir($dir)) {
die("$dir is not a directory.Exiting...\n");
}
-
+
$name = basename($dir);
$style_name = "template_{$name}";
$qb = new midgardQueryBuilder('midgard_style');
@@ -81,14 +81,14 @@
}
echo "Installing template: " . $style->name ;
-
+
$files = dir($dir);
$elements = array();
while (($file = $files->read()) !== false ) {
if (substr($file,0, 1) == '.' || !is_file("$dir/$file") ) continue;
$path = pathinfo($file);
if ($path['extension'] == 'php') {
-
+
$elements[] = str_replace('.php', '', $path['basename']);
} else {
echo "@todo: install static $file\n";
@@ -100,7 +100,7 @@
}
echo "Remember that you have to clear the midgard pagecache to see effects!\n";
-
+
}
function add_element_to_style ($style, $element_name) {
@@ -108,7 +108,7 @@
$file = $dir . "/" . $element_name . ".php";
if (!is_file($file) || ! is_readable($file)) {
- die("$file is not accessable!\n");
+ die("$file is not accessible!\n");
}
$qb = new MidgardQueryBuilder('midgard_element');
@@ -132,12 +132,12 @@
}
else
{
-
+
$element = $elements[0];
// check if there is a newer version in the db.
$date = strtotime ( $element->metadata->revised ) ;
-
- //YYYY-MM-DDThh:mm:ss
+
+ //YYYY-MM-DDThh:mm:ss
$file_date = filemtime($file);
if ($date > $file_date && !$this->pompt("Do you want to overwrite the current $element_name element?", false ) ) {
return;
@@ -162,32 +162,32 @@
$defaultStr = 'Yes/No';
}
$fp = fopen('php://stdin', 'r');
-
+
while (true) {
echo $question, " ", $defaultStr, ": ";
$response = trim(fgets($fp, 8192));
-
+
if (!is_null($default) AND $response == '') {
return $default;
}
-
+
switch (strtolower($response)) {
case 'y':
case '1':
case 'yes':
case 'true':
return true;
-
+
case 'n':
case '0':
case 'no':
case 'false':
return false;
-
+
default:
continue;
}
- }
+ }
}
}
Modified: trunk/midcom/midcom.helper.datamanager/datatype.php
==============================================================================
--- trunk/midcom/midcom.helper.datamanager/datatype.php (original)
+++ trunk/midcom/midcom.helper.datamanager/datatype.php Wed Jan 9 17:07:17 2008
@@ -344,7 +344,7 @@
*
* @return mixed The default ("empty") value for the widget.
* @access private
- * @see midcom_helper_datamanager_datatype::_get_empty_value();
+ * @see midcom_helper_datamanager_datatype::_get_empty_value()
*/
function _get_default_value()
{
Modified: trunk/midcom/midcom.helper.datamanager/lib_markdown.php
==============================================================================
--- trunk/midcom/midcom.helper.datamanager/lib_markdown.php (original)
+++ trunk/midcom/midcom.helper.datamanager/lib_markdown.php Wed Jan 9 17:07:17 2008
@@ -1,20 +1,29 @@
<?php
-
+/**
+ * @package midcom.helper.datamanager
+ * @author The Midgard Project, http://www.midgard-project.org
+ * @copyright The Midgard Project, http://www.midgard-project.org
+ * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
+ */
+
+/**
+ *
+ */
#
# Markdown - A text-to-HTML conversion tool for web writers
#
-# Copyright (c) 2004 John Gruber
+# Copyright (c) 2004 John Gruber
# <http://daringfireball.net/projects/markdown/>
#
-# Copyright (c) 2004 Michel Fortin - PHP Port
+# Copyright (c) 2004 Michel Fortin - PHP Port
# <http://www.michelf.com/projects/php-markdown/>
#
global $MarkdownPHPVersion, $MarkdownSyntaxVersion,
$md_empty_element_suffix, $md_tab_width,
- $md_nested_brackets_depth, $md_nested_brackets,
- $md_escape_table, $md_backslash_escape_table,
+ $md_nested_brackets_depth, $md_nested_brackets,
+ $md_escape_table, $md_backslash_escape_table,
$md_list_level;
$MarkdownPHPVersion = '1.0.1'; # Fri 17 Dec 2004
@@ -91,9 +100,9 @@
#
# Regex to match balanced [brackets].
-# Needed to insert a maximum bracked depth while converting to PHP.
+# Needed to insert a maximum bracket depth while converting to PHP.
$md_nested_brackets_depth = 6;
-$md_nested_brackets =
+$md_nested_brackets =
str_repeat('(?>[^\[\]]+|\[', $md_nested_brackets_depth).
str_repeat('\])*', $md_nested_brackets_depth);
@@ -278,7 +287,7 @@
[ ]{0,'.$less_than_tab.'}
<(hr) # start tag = $2
\b # word break
- ([^<>])*? #
+ ([^<>])*? #
/?> # the matching end tag
[ \t]*
(?=\n{2,}|\Z) # followed by a blank line or end of document
@@ -333,7 +342,7 @@
array('{^[ ]{0,2}([ ]?\*[ ]?){3,}[ \t]*$}mx',
'{^[ ]{0,2}([ ]? -[ ]?){3,}[ \t]*$}mx',
'{^[ ]{0,2}([ ]? _[ ]?){3,}[ \t]*$}mx'),
- "\n<hr$md_empty_element_suffix\n",
+ "\n<hr$md_empty_element_suffix\n",
$text);
$text = _DoLists($text);
@@ -485,7 +494,7 @@
if ( isset( $md_titles[$link_id] ) ) {
$title = $md_titles[$link_id];
$title = str_replace(array('*', '_'),
- array($md_escape_table['*'],
+ array($md_escape_table['*'],
$md_escape_table['_']), $title);
$result .= " title=\"$title\"";
}
@@ -505,7 +514,7 @@
# We've got to encode these to avoid conflicting with italics/bold.
$url = str_replace(array('*', '_'),
- array($md_escape_table['*'], $md_escape_table['_']),
+ array($md_escape_table['*'], $md_escape_table['_']),
$url);
$result = "<a href=\"$url\"";
if (isset($title)) {
@@ -515,7 +524,7 @@
$title);
$result .= " title=\"$title\"";
}
-
+
$result .= ">$link_text</a>";
return $result;
@@ -543,7 +552,7 @@
\]
)
- }xs',
+ }xs',
'_DoImages_reference_callback', $text);
#
@@ -593,7 +602,7 @@
if (isset($md_titles[$link_id])) {
$title = $md_titles[$link_id];
$title = str_replace(array('*', '_'),
- array($md_escape_table['*'],
+ array($md_escape_table['*'],
$md_escape_table['_']), $title);
$result .= " title=\"$title\"";
}
@@ -639,7 +648,7 @@
# Setext-style headers:
# Header 1
# ========
- #
+ #
# Header 2
# --------
#
@@ -705,7 +714,7 @@
)
)
'; // mx
-
+
# We use a different prefix before nested lists than top-level lists.
# See extended comment in _ProcessListItems().
@@ -731,7 +740,7 @@
$marker_ul = '[*+-]';
$marker_ol = '\d+[.]';
$marker_any = "(?:$marker_ul|$marker_ol)";
-
+
$list = $matches[1];
$list_type = preg_match("/$marker_ul/", $matches[3]) ? "ul" : "ol";
# Turn double returns into triple returns, so that we can make a
@@ -749,7 +758,7 @@
# into individual list items.
#
global $md_list_level;
-
+
# The $md_list_level global keeps track of when we're inside a list.
# Each time we enter a list, we increment it; when we leave a list,
# we decrement. If it's zero, we're not in a list anymore.
@@ -770,7 +779,7 @@
# without resorting to mind-reading. Perhaps the solution is to
# change the syntax rules such that sub-lists must start with a
# starting cardinal number; e.g. "1." or "a.".
-
+
$md_list_level++;
# trim trailing blank lines:
@@ -899,11 +908,11 @@
$_ = str_replace('&', '&', $_);
# Do the angle bracket song and dance:
- $_ = str_replace(array('<', '>'),
+ $_ = str_replace(array('<', '>'),
array('<', '>'), $_);
# Now, escape characters that are magic in Markdown:
- $_ = str_replace(array_keys($md_escape_table),
+ $_ = str_replace(array_keys($md_escape_table),
array_values($md_escape_table), $_);
return $_;
@@ -945,7 +954,7 @@
$bq = preg_replace('/^/m', " ", $bq);
# These leading spaces screw with <pre> content, so we need to fix that:
- $bq = preg_replace_callback('{(\s*<pre>.+?</pre>)}sx',
+ $bq = preg_replace_callback('{(\s*<pre>.+?</pre>)}sx',
'_DoBlockQuotes_callback2', $bq);
return "<blockquote>\n$bq\n</blockquote>\n\n";
@@ -999,7 +1008,7 @@
# Ampersand-encoding based entirely on Nat Irons's Amputator MT plugin:
# http://bumppo.net/projects/amputator/
- $text = preg_replace('/&(?!#?[xX]?(?:[0-9a-fA-F]+|\w+);)/',
+ $text = preg_replace('/&(?!#?[xX]?(?:[0-9a-fA-F]+|\w+);)/',
'&', $text);;
# Encode naked <'s
@@ -1023,7 +1032,7 @@
function _DoAutoLinks($text) {
- $text = preg_replace("!<((https?|ftp):[^'\">\\s]+)>!",
+ $text = preg_replace("!<((https?|ftp):[^'\">\\s]+)>!",
'<a href="\1">\1</a>', $text);
# Email addresses: <address at domain.foo>
@@ -1063,7 +1072,7 @@
$length = strlen($addr);
# leave ':' alone (to spot mailto: later)
- $addr = preg_replace_callback('/([^\:])/',
+ $addr = preg_replace_callback('/([^\:])/',
'_EncodeEmailAddress_callback', $addr);
$addr = "<a href=\"$addr\">$addr</a>";
@@ -1088,7 +1097,7 @@
# Swap back in all the special characters we've hidden.
#
global $md_escape_table;
- return str_replace(array_values($md_escape_table),
+ return str_replace(array_values($md_escape_table),
array_keys($md_escape_table), $text);
}
@@ -1107,7 +1116,7 @@
# the second is the actual value.
#
#
-# Regular expression derived from the _tokenize() subroutine in
+# Regular expression derived from the _tokenize() subroutine in
# Brad Choate's MTRegex plugin.
# <http://www.bradchoate.com/past/mtregex.php>
#
@@ -1121,7 +1130,7 @@
$parts = preg_split("{($match)}", $str, -1, PREG_SPLIT_DELIM_CAPTURE);
foreach ($parts as $part) {
- if (++$index % 2 && $part != '')
+ if (++$index % 2 && $part != '')
array_push($tokens, array('text', $part));
else
array_push($tokens, array('tag', $part));
@@ -1147,13 +1156,13 @@
#
global $md_tab_width;
- # For each line we separate the line in blocks delemited by
+ # For each line we separate the line in blocks delimited by
# tab characters. Then we reconstruct the line adding the appropriate
- # number of space charcters.
-
+ # number of space characters.
+
$lines = explode("\n", $text);
$text = "";
-
+
foreach ($lines as $line) {
# Split in blocks.
$blocks = explode("\t", $line);
@@ -1173,7 +1182,7 @@
function _UnslashQuotes($text) {
#
-# This function is useful to remove automaticaly slashed double quotes
+# This function is useful to remove automatically slashed double quotes
# when using preg_replace and evaluating an expression.
# Parameter: String.
# Returns: The string with any slash-double-quote (\") sequence replaced
@@ -1221,7 +1230,7 @@
Version History
----------------
+---------------
See the readme file for detailed release notes for this version.
@@ -1233,22 +1242,22 @@
Author & Contributors
---------------------
-Original Perl version by John Gruber
+Original Perl version by John Gruber
<http://daringfireball.net/>
-PHP port and other contributions by Michel Fortin
+PHP port and other contributions by Michel Fortin
<http://www.michelf.com/>
Copyright and License
---------------------
-Copyright (c) 2004 Michel Fortin
-<http://www.michelf.com/>
+Copyright (c) 2004 Michel Fortin
+<http://www.michelf.com/>
All rights reserved.
-Copyright (c) 2003-2004 John Gruber
-<http://daringfireball.net/>
+Copyright (c) 2003-2004 John Gruber
+<http://daringfireball.net/>
All rights reserved.
Redistribution and use in source and binary forms, with or without
Modified: trunk/midcom/midcom.helper.datamanager/widget_account.php
==============================================================================
--- trunk/midcom/midcom.helper.datamanager/widget_account.php (original)
+++ trunk/midcom/midcom.helper.datamanager/widget_account.php Wed Jan 9 17:07:17 2008
@@ -22,12 +22,12 @@
*
* <b>Sample configuration</b>
*
- * <pre>
+ * <code>
* "account" => array (
* "description" => "Account",
* "datatype" => "account"
* ),
- * </pre>
+ * </code>
*
* <b>CSS Styles in use by the Widget</b>
*
Modified: trunk/midcom/midcom.helper.datamanager2/type/select.php
==============================================================================
--- trunk/midcom/midcom.helper.datamanager2/type/select.php (original)
+++ trunk/midcom/midcom.helper.datamanager2/type/select.php Wed Jan 9 17:07:17 2008
@@ -118,7 +118,7 @@
* The options available to the client. You should not access this variable directly,
* as this information may be loaded on demand, depending on the types configuration.
*
- * @see get_all_options();
+ * @see get_all_options()
* @var Array
* @access public
*/
Modified: trunk/midcom/midgard.admin.sitegroup/bin/create-host.php
==============================================================================
--- trunk/midcom/midgard.admin.sitegroup/bin/create-host.php (original)
+++ trunk/midcom/midgard.admin.sitegroup/bin/create-host.php Wed Jan 9 17:07:17 2008
@@ -7,6 +7,10 @@
* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
*
*/
+
+/**
+ * @ignore
+ */
ini_set('include_path','..:'.ini_get('include_path'));
error_reporting(E_ALL);
Modified: trunk/midcom/midgard.admin.sitegroup/bin/create-sitegroup.php
==============================================================================
--- trunk/midcom/midgard.admin.sitegroup/bin/create-sitegroup.php (original)
+++ trunk/midcom/midgard.admin.sitegroup/bin/create-sitegroup.php Wed Jan 9 17:07:17 2008
@@ -7,6 +7,10 @@
* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
*
*/
+
+/**
+ * @ignore
+ */
ini_set('include_path','..:'.ini_get('include_path'));
require_once 'Console/Getargs.php';
Modified: trunk/midcom/midgard.admin.sitegroup/creation/host.php
==============================================================================
--- trunk/midcom/midgard.admin.sitegroup/creation/host.php (original)
+++ trunk/midcom/midgard.admin.sitegroup/creation/host.php Wed Jan 9 17:07:17 2008
@@ -641,7 +641,9 @@
}
-
+/**
+ * @package midgard.admin.sitegroup
+ */
class midgard_admin_sitegroup_creation_host_17 extends midgard_admin_sitegroup_creation_host
{
/**
@@ -747,6 +749,9 @@
}
+/**
+ * @package midgard.admin.sitegroup
+ */
class midgard_admin_sitegroup_creation_host_18 extends midgard_admin_sitegroup_creation_host {
Modified: trunk/midcom/midgard.admin.sitewizard/sitetemplate.php
==============================================================================
--- trunk/midcom/midgard.admin.sitewizard/sitetemplate.php (original)
+++ trunk/midcom/midgard.admin.sitewizard/sitetemplate.php Wed Jan 9 17:07:17 2008
@@ -9,6 +9,8 @@
/**
* midgard.admin.sitewizard site template handling interface class.
+ *
+ * @package midgard.admin.sitewizard
*/
class midgard_admin_sitewizard_sitetemplate extends midcom_baseclasses_components_handler
{
Modified: trunk/midcom/net.nehmer.account/plugins/midgard_admin_sitewizard_plugin.php
==============================================================================
--- trunk/midcom/net.nehmer.account/plugins/midgard_admin_sitewizard_plugin.php (original)
+++ trunk/midcom/net.nehmer.account/plugins/midgard_admin_sitewizard_plugin.php Wed Jan 9 17:07:17 2008
@@ -8,6 +8,8 @@
/**
* This is a plugin for creating user home topic
+ *
+ * @package net.nehmer.account
*/
class midgard_admin_sitewizard_plugin extends midcom_baseclasses_components_handler
{
Modified: trunk/midcom/net.nehmer.markdown/lib/markdown.php
==============================================================================
--- trunk/midcom/net.nehmer.markdown/lib/markdown.php (original)
+++ trunk/midcom/net.nehmer.markdown/lib/markdown.php Wed Jan 9 17:07:17 2008
@@ -156,7 +156,7 @@
#
# Regex to match balanced [brackets].
-# Needed to insert a maximum bracked depth while converting to PHP.
+# Needed to insert a maximum bracket depth while converting to PHP.
$md_nested_brackets_depth = 6;
$md_nested_brackets =
str_repeat('(?>[^\[\]]+|\[', $md_nested_brackets_depth).
@@ -692,7 +692,7 @@
function _HashBlock($text) {
#
# Called whenever a tag must be hashed. When a function insert a block-level
-# tag in $text, it pass through this function and is automaticaly escaped,
+# tag in $text, it pass through this function and is automatically escaped,
# which remove the need to call _HashHTMLBlocks at every step.
#
# Swap back any tag hash found in $text so we do not have to _UnhashTags
@@ -712,7 +712,7 @@
if ($hash_html_blocks) {
# We need to escape raw HTML in Markdown source before doing anything
# else. This need to be done for each block, and not only at the
- # begining in the Markdown function since hashed blocks can be part of
+ # beginning in the Markdown function since hashed blocks can be part of
# a list item and could have been indented. Indented blocks would have
# been seen as a code block in previous pass of _HashHTMLBlocks.
$text = _HashHTMLBlocks($text);
@@ -1866,7 +1866,7 @@
#
global $md_tab_width;
- # For each line we separate the line in blocks delemited by
+ # For each line we separate the line in blocks delimited by
# tab characters. Then we reconstruct every line by adding the
# appropriate number of space between each blocks.
@@ -1892,7 +1892,7 @@
function _UnslashQuotes($text) {
#
-# This function is useful to remove automaticaly slashed double quotes
+# This function is useful to remove automatically slashed double quotes
# when using preg_replace and evaluating an expression.
# Parameter: String.
# Returns: The string with any slash-double-quote (\") sequence replaced
Modified: trunk/midcom/net.nemein.rss/feed.php
==============================================================================
--- trunk/midcom/net.nemein.rss/feed.php (original)
+++ trunk/midcom/net.nemein.rss/feed.php Wed Jan 9 17:07:17 2008
@@ -8,6 +8,8 @@
/**
* MidCOM wrapped class for access to stored queries
+ *
+ * @package net.nemein.rss
*/
class net_nemein_rss_feed_dba extends __net_nemein_rss_feed_dba
{
Modified: trunk/midcom/net.nemein.teams/plugins/midgard_admin_sitewizard_plugin.php
==============================================================================
--- trunk/midcom/net.nemein.teams/plugins/midgard_admin_sitewizard_plugin.php (original)
+++ trunk/midcom/net.nemein.teams/plugins/midgard_admin_sitewizard_plugin.php Wed Jan 9 17:07:17 2008
@@ -1,8 +1,15 @@
<?php
-
+/**
+ * @package net.nemein.teams
+ * @author The Midgard Project, http://www.midgard-project.org
+ * @copyright The Midgard Project, http://www.midgard-project.org
+ * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
+ */
/**
* This is a plugin for creating user home topic
+ *
+ * @package net.nemein.teams
*/
class midgard_admin_sitewizard_plugin extends midcom_baseclasses_components_handler
{
Modified: trunk/midcom/net.nemein.wiki/link.php
==============================================================================
--- trunk/midcom/net.nemein.wiki/link.php (original)
+++ trunk/midcom/net.nemein.wiki/link.php Wed Jan 9 17:07:17 2008
@@ -8,6 +8,8 @@
/**
* MidCOM wrapped class for access to stored queries
+ *
+ * @package net.nemein.wiki
*/
class net_nemein_wiki_link_dba extends __net_nemein_wiki_link_dba
{
Modified: trunk/midcom/no.bergfald.rcs/backends/aegir_rcs_functions.php
==============================================================================
--- trunk/midcom/no.bergfald.rcs/backends/aegir_rcs_functions.php (original)
+++ trunk/midcom/no.bergfald.rcs/backends/aegir_rcs_functions.php Wed Jan 9 17:07:17 2008
@@ -369,7 +369,7 @@
break;
case 1:
if (eregi("^[ ]*<([a-z]+)><!\[CDATA\[(.*)$", $tempdata[$i], $args)){
- // begining CDATA!
+ // beginning CDATA!
$status["block"] = $args[1];
$status["level"] = 2;
$dataarray[$status["block"]] = $args[2] . "\n";
Modified: trunk/midcom/no.bergfald.rcs/backends/nemein_rcs_functions.php
==============================================================================
--- trunk/midcom/no.bergfald.rcs/backends/nemein_rcs_functions.php (original)
+++ trunk/midcom/no.bergfald.rcs/backends/nemein_rcs_functions.php Wed Jan 9 17:07:17 2008
@@ -447,7 +447,7 @@
break;
case 1:
if (eregi("^[ ]*<([a-z]+)><!\[CDATA\[(.*)$", $tempdata[$i], $args)){
- // begining CDATA!
+ // beginning CDATA!
$status[block] = $args[1];
$status[level] = 2;
$dataarray[$status[block]] = $args[2] . "\n";
Modified: trunk/midcom/no.odindata.quickform2/emailgenerator.php
==============================================================================
--- trunk/midcom/no.odindata.quickform2/emailgenerator.php (original)
+++ trunk/midcom/no.odindata.quickform2/emailgenerator.php Wed Jan 9 17:07:17 2008
@@ -11,6 +11,8 @@
* quickform email.
*
* You should extend this class and change the execute method only.
+ *
+ * @package no.odindata.quickform2
*/
class no_odindata_quickform2_emailgenerator
{
Modified: trunk/midcom/org.openpsa.directmarketing/support/link_detector.php
==============================================================================
--- trunk/midcom/org.openpsa.directmarketing/support/link_detector.php (original)
+++ trunk/midcom/org.openpsa.directmarketing/support/link_detector.php Wed Jan 9 17:07:17 2008
@@ -3,6 +3,7 @@
* @package org.openpsa.directmarketing
* @license http://www.gnu.org/licenses/gpl.html GNU General Public License
*
+ *
* Copyright (c) 2006 Jukka Zitting <jz at yukatan.fi>
* This file is part of OpenPSA.
*
@@ -21,6 +22,9 @@
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/
+/**
+ *
+ */
if (isset($_GET["token"]))
{
$token = $_GET["token"];
Modified: trunk/midcom/org.openpsa.documents/document_midcomdba.php
==============================================================================
--- trunk/midcom/org.openpsa.documents/document_midcomdba.php (original)
+++ trunk/midcom/org.openpsa.documents/document_midcomdba.php Wed Jan 9 17:07:17 2008
@@ -8,7 +8,7 @@
/**
* @package org.openpsa.documents
- * @todo: This is a hotfix.
+ * @todo This is a hotfix.
*/
class midcom_org_openpsa_document extends __midcom_org_openpsa_document
{
Modified: trunk/midcom/org.openpsa.helpers/array2code.php
==============================================================================
--- trunk/midcom/org.openpsa.helpers/array2code.php (original)
+++ trunk/midcom/org.openpsa.helpers/array2code.php Wed Jan 9 17:07:17 2008
@@ -1,9 +1,16 @@
<?php
/**
* returns array as code to generate it
+ *
* @package org.openpsa.helpers
+ * @author Eero af Heurlin, http://www.iki.fi/rambo
+ * @copyright Nemein Oy, http://www.nemein.com
+ * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
*/
+/**
+ * returns array as code to generate it
+ */
if (!function_exists('array2code')) {
function array2code($arr, $level=0, $code = '')
{
Modified: trunk/midcom/org.openpsa.helpers/dm_savecancel.php
==============================================================================
--- trunk/midcom/org.openpsa.helpers/dm_savecancel.php (original)
+++ trunk/midcom/org.openpsa.helpers/dm_savecancel.php Wed Jan 9 17:07:17 2008
@@ -8,6 +8,10 @@
* @copyright Nemein Oy, http://www.nemein.com
* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
*/
+
+/**
+ * Function for adding JavaScript buttons for saving/cancelling DataManager form via toolbar
+ */
function org_openpsa_helpers_dm_savecancel(&$toolbar, &$handler)
{
if ( !is_object($toolbar)
Modified: trunk/midcom/org.openpsa.helpers/resources.php
==============================================================================
--- trunk/midcom/org.openpsa.helpers/resources.php (original)
+++ trunk/midcom/org.openpsa.helpers/resources.php Wed Jan 9 17:07:17 2008
@@ -6,9 +6,13 @@
* @version $Id: resources.php,v 1.2 2005/10/14 06:59:52 bergius Exp $
* @copyright Nemein Oy, http://www.nemein.com
* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
- * @return Array List of persons appropriate for the current selection
*/
+/**
+ * Helper function for listing virtual groups of user
+ *
+ * @return Array List of persons appropriate for the current selection
+ */
function org_openpsa_helpers_resources()
{
// List members of selected ACL group for usage in DM arrays
Modified: trunk/midcom/org.openpsa.helpers/schema_modifier.php
==============================================================================
--- trunk/midcom/org.openpsa.helpers/schema_modifier.php (original)
+++ trunk/midcom/org.openpsa.helpers/schema_modifier.php Wed Jan 9 17:07:17 2008
@@ -8,6 +8,9 @@
* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
*/
+/**
+ * @return boolean Indicating success.
+ */
function org_openpsa_helpers_schema_modifier(&$datamanager, $field, $key, $value, $schema = 'default', $create_field = true)
{
if (array_key_exists($schema, $datamanager->_layoutdb))
Modified: trunk/midcom/org.openpsa.helpers/sprint_r.php
==============================================================================
--- trunk/midcom/org.openpsa.helpers/sprint_r.php (original)
+++ trunk/midcom/org.openpsa.helpers/sprint_r.php Wed Jan 9 17:07:17 2008
@@ -1,9 +1,16 @@
<?php
/**
* returns output of print_r as string
+ *
* @package org.openpsa.helpers
+ * @author Eero af Heurlin, http://www.iki.fi/rambo
+ * @copyright Nemein Oy, http://www.nemein.com
+ * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
*/
+/**
+ * returns output of print_r as string
+ */
if (!function_exists('sprint_r')) {
function sprint_r($var) {
ob_start();
Modified: trunk/midcom/org.openpsa.helpers/task_groups.php
==============================================================================
--- trunk/midcom/org.openpsa.helpers/task_groups.php (original)
+++ trunk/midcom/org.openpsa.helpers/task_groups.php Wed Jan 9 17:07:17 2008
@@ -9,6 +9,9 @@
* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
*/
+/**
+ * Function for listing groups tasks contacts are members of
+ */
function org_openpsa_helpers_task_groups(&$task, $mode = 'id')
{
//TODO: Localize something for the empty choice ?
Modified: trunk/midcom/org.openpsa.helpers/tasks.php
==============================================================================
--- trunk/midcom/org.openpsa.helpers/tasks.php (original)
+++ trunk/midcom/org.openpsa.helpers/tasks.php Wed Jan 9 17:07:17 2008
@@ -8,6 +8,9 @@
* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
*/
+/**
+ * Helper function for listing tasks user can see
+ */
function org_openpsa_helpers_projects($add_all = false, $display_tasks = false, $require_privileges = false)
{
//Make sure the class we need exists
Modified: trunk/midcom/org.openpsa.helpers/workgroups.php
==============================================================================
--- trunk/midcom/org.openpsa.helpers/workgroups.php (original)
+++ trunk/midcom/org.openpsa.helpers/workgroups.php Wed Jan 9 17:07:17 2008
@@ -8,6 +8,9 @@
* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
*/
+/*
+ * Helper function for listing virtual groups of user
+ */
function org_openpsa_helpers_workgroups($add_me = 'last', $show_members = false)
{
//mgd_debug_start();
Modified: trunk/midcom/org.openpsa.sales/sort_helper.php
==============================================================================
--- trunk/midcom/org.openpsa.sales/sort_helper.php (original)
+++ trunk/midcom/org.openpsa.sales/sort_helper.php Wed Jan 9 17:07:17 2008
@@ -7,6 +7,9 @@
* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
*/
+/**
+ *
+ */
function org_openpsa_sales_sort_link($mode, $label, $element = 'th')
{
$static_base = MIDCOM_STATIC_URL . '/';
Modified: trunk/midcom/org.routamc.photostream/midcom/interfaces.php
==============================================================================
--- trunk/midcom/org.routamc.photostream/midcom/interfaces.php (original)
+++ trunk/midcom/org.routamc.photostream/midcom/interfaces.php Wed Jan 9 17:07:17 2008
@@ -6,6 +6,9 @@
* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License
*/
+/**
+ * @package org.routamc.photostream
+ */
class org_routamc_photostream_interface extends midcom_baseclasses_components_interface
{
/**
Modified: trunk/midcom/org.routamc.photostream/phpFlickr.php
==============================================================================
--- trunk/midcom/org.routamc.photostream/phpFlickr.php (original)
+++ trunk/midcom/org.routamc.photostream/phpFlickr.php Wed Jan 9 17:07:17 2008
@@ -1,5 +1,10 @@
<?php
-/* phpFlickr Class 2.0.0
+/**
+ * @package org.routamc.photostream
+ */
+
+/**
+ * phpFlickr Class 2.0.0
* Written by Dan Coulter (dan at dancoulter.com)
* Sourceforge Project Page: http://www.sourceforge.net/projects/phpflickr/
* Released under GNU Lesser General Public License (http://www.gnu.org/copyleft/lgpl.html)
Modified: trunk/midcom/se.anykey.mmslib/mmslib.php
==============================================================================
--- trunk/midcom/se.anykey.mmslib/mmslib.php (original)
+++ trunk/midcom/se.anykey.mmslib/mmslib.php Wed Jan 9 17:07:17 2008
@@ -248,6 +248,8 @@
*
* The Part class is just a container for various attachments of different content types.
* The data itself is not stored though, it merely contains a reference to the file
+ *
+ * @package se.anykey.mmslib
*/
class Part
@@ -318,6 +320,8 @@
*
* Limitations: The parsing of Content-type for parts is not complete so you won't get
* the filename for instance.
+ *
+ * @package se.anykey.mmslib
*/
class MMSDecoder
@@ -925,6 +929,8 @@
* content. The only header currently supported for parts is the simple
* Content-type header. So currently this can only be used to deliver
* chunks of content collections - no complete presentations
+ *
+ * @package se.anykey.mmslib
*/
class MMSEncoder
@@ -1167,6 +1173,8 @@
* This class is used to send out the notification that will point the phone to the
* MMS that is located at a certain URL. The SMS service is your simple web interface
* using HTTP 1.1 GET. Change this to fit your system and your way of SMS sending
+ *
+ * @package se.anykey.mmslib
*/
class MMSNotifyer
{
More information about the midcom-commits
mailing list
--- trunk/midcom/midcom.core/midcom/exec/index-legacy-attachments.php (original)
+++ trunk/midcom/midcom.core/midcom/exec/index-legacy-attachments.php Wed Jan 9 17:07:17 2008
@@ -10,7 +10,7 @@
* - Any for of datamanager controlled attachments used for storage of long
* varibales, recognized by their data_ name prefix.
* - Any blob/image type attachments, recognized by some of their parameters.
* - Any leaves associated with net.siriux.photos topics are skipped completely.
*
* NAP will used to traverse the registered topic tree, indexing all attachments
* of each node and leaf found.
@@ -19,8 +19,8 @@
*
* <i>Handle with care!</i> This handler unconditionally indexes all attachments
* found and not filtered along the above conditions. This might lead to attachments
- * being indexed accidentially or, which is even worse, already indexed attachments
- * being overwritten, loosing additional information that might be present.
+ * beeing indexed accidentially or, which is even worse, already indexed attachments
+ * beeing overwritten, loosing additional information that might be present.
*
* @package midcom
* @author The Midgard Project, http://www.midgard-project.org
@@ -118,7 +118,7 @@
$leaf = $nap->get_leaf($leafid);
if (is_null($leaf[MIDCOM_NAV_OBJECT]))
{
- debug_add("The leaf {$leafid} does not have an associated MidgardObject, skipping it.", MIDCOM_LOG_INFO);
+ debug_add("The leaf {$leafid} does not have an accociated MidgardObject, skipping it.", MIDCOM_LOG_INFO);
debug_print_r('Leaf strucuture dump:', $leaf);
continue;
}
@@ -10,7 +10,7 @@
* varibales, recognized by their data_ name prefix.
* - Any blob/image type attachments, recognized by some of their parameters.
- * - Any leaves associated with net.siriux.photos topics are skipped completely.
+ * - Any leaves accociated with net.siriux.photos topics are skipped completly.
*
* NAP will used to traverse the registered topic tree, indexing all attachments
Modified: trunk/midcom/midcom.core/midcom/helper/metadata.php
==============================================================================